package com.yizhi.live.application.service.impl;

import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.service.impl.ServiceImpl;
import com.yizhi.application.orm.id.IdGenerator;
import com.yizhi.live.application.domain.ScopeAuthorization;
import com.yizhi.live.application.mapper.ScopeAuthorizationMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import com.yizhi.live.application.service.IScopeAuthorizationService;

import java.util.List;

/**
 * <p>
 * 直播授权课件范围表 服务实现类
 * </p>
 *
 * @author fulan123
 * @since 2018-04-10
 */
@Service
@Transactional
public class ScopeAuthorizationServiceImpl extends ServiceImpl<ScopeAuthorizationMapper, ScopeAuthorization> implements IScopeAuthorizationService {

    private Logger logger = LoggerFactory.getLogger(ScopeAuthorizationServiceImpl.class);

    @Autowired
    IdGenerator idGenerator;

    @Override
    public Boolean insertList(List<ScopeAuthorization> list) {
        if (list.size() > 0) {
            //保存之前先删除 修改时时 不用做数据对比
            Long liveId = list.get(0).getLiveId();
            this.baseMapper.deleteAuthorize(liveId);
            //保存
            for (ScopeAuthorization scopeAuthorization1 : list) {
                scopeAuthorization1.setId(idGenerator.generate());
            }
            return this.baseMapper.insertList(list);
        } else {
            return Boolean.FALSE;
        }
    }

    @Override
    public Boolean insertAllList(List<ScopeAuthorization> list) {
        if (!CollectionUtils.isEmpty(list)) {
            Long liveId = list.get(0).getLiveId();
            this.baseMapper.deleteAuthorize(liveId);
            for (ScopeAuthorization scopeAuthorization1 : list) {
                scopeAuthorization1.setId(idGenerator.generate());
            }
            return this.baseMapper.insertList(list);
        } else {
            logger.error("列表为空");
            return Boolean.FALSE;
        }

    }

	@Override
	public List<ScopeAuthorization> listScopeAuthorization(Long liveId) {
		// TODO Auto-generated method stub
		ScopeAuthorization scopeAuthorization=new ScopeAuthorization();
		scopeAuthorization.setLiveId(liveId);
		EntityWrapper<ScopeAuthorization> wrapper=new EntityWrapper<ScopeAuthorization>(scopeAuthorization);
		return this.selectList(wrapper);
	}


}
