package com.yizhi.live.application.util;

import com.yizhi.core.application.context.RequestContext;
import com.yizhi.core.application.event.EventWrapper;
import com.yizhi.core.application.publish.CloudEventPublisher;
import com.yizhi.live.application.domain.LiveActivity;
import com.yizhi.live.application.vo.MessageRemindVo;
import com.yizhi.live.application.vo.MessageTaskRemindVo;
import com.yizhi.message.application.constans.Constans;
import com.yizhi.message.application.enums.RelationType;
import com.yizhi.message.application.vo.TaskVo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;

@Component
public class LiveEvenSendMessage {

    @Autowired
    private CloudEventPublisher cloudEventPublisher;

    private Logger logger = LoggerFactory.getLogger(LiveEvenSendMessage.class);


    /**
     * 系统模板,发消息
     *
     * @param liveActivity 业务参数对象
     */
    public void systemSendMessage(LiveActivity liveActivity, MessageRemindVo remindVo, RequestContext context) {
        com.yizhi.message.application.vo.MessageRemindVo vo = new com.yizhi.message.application.vo.MessageRemindVo();
        //共用参数
        vo.setMessageType(2);
        vo.setRelationId(liveActivity.getId());
        vo.setRelationType(RelationType.ZB.getKey());
        if (context == null) {
            context = new RequestContext();
            context.setCompanyId(liveActivity.getCompanyId());
            context.setSiteId(liveActivity.getSiteId());
            context.setAccountName(liveActivity.getCreateByName());
            context.setAccountId(liveActivity.getCreateById());
        }
        vo.setRequestContext(context);
        if (vo.getMessageType() == null || vo.getRelationId() == null || vo.getRelationType() == null) {
            logger.info("messageType:"+remindVo.getMessageType()+"||"+"RelationId:"+remindVo.getRelationId()
                    +"||"+"RelationType:"+remindVo.getRelationType());
            logger.info("相关参数缺失！！");
            return;
        }
        if (remindVo.getHasDeleted()) {
            vo.setHasDeleted(remindVo.getHasDeleted());
            cloudEventPublisher.publish(Constans.MESSAGE_QUEUE, new EventWrapper<com.yizhi.message.application.vo.MessageRemindVo>(null, vo));
        } else {
            //修改直播的状态
            if (remindVo.getTaskStatusUpdate()) {
                //1 为消息业务可发送状态  0 则不行
                vo.setTaskStatus(liveActivity.getShelves().equals(1) ? 1 : 0);
                vo.setTaskStatusUpdate(remindVo.getTaskStatusUpdate());
                cloudEventPublisher.publish(Constans.MESSAGE_QUEUE, new EventWrapper<com.yizhi.message.application.vo.MessageRemindVo>(null, vo));
                logger.info("发送修改业务状态消息成功=====================");
                return;
            }
            if (liveActivity != null) {
                if (!CollectionUtils.isEmpty(remindVo.getMessageTaskRemindVos())) {

                    com.yizhi.message.application.vo.TaskVo taskVo = new TaskVo();
                    taskVo.setTaskName(liveActivity.getTitle());
                    taskVo.setTaskStratTime(liveActivity.getStartTime());
                    taskVo.setTaskEndTime(liveActivity.getEndTime());
                    vo.setTaskStatus(liveActivity.getShelves().equals(1) ? 1 : 0);
                    vo.setMessageType(remindVo.getMessageType());
                    vo.setMessageId(remindVo.getMessageId());
                    vo.setIsChangge(remindVo.getIsChangge());
                    List<MessageTaskRemindVo> m=  remindVo.getMessageTaskRemindVos();
                    List<com.yizhi.message.application.vo.MessageTaskRemindVo> m2=new ArrayList<>();
                    for (MessageTaskRemindVo m1:m
                         ) {
                        com.yizhi.message.application.vo.MessageTaskRemindVo mx=new com.yizhi.message.application.vo.MessageTaskRemindVo();
                        BeanUtils.copyProperties(m1,mx);
                        m2.add(mx);
                    }
                    vo.setMessageTaskRemindVos(m2);
                    vo.setSendType(remindVo.getSendType());
                    vo.setVisibleRange(remindVo.getVisibleRange());
                    vo.setTaskVo(taskVo);
                    if (vo.getMessageId() == null || vo.getSendType() == null || vo.getVisibleRange() == null) {
                        logger.info("messageID:"+remindVo.getMessageId()+"||"+"sendType:"+remindVo.getSendType()
                                +"||"+"VisibleRange:"+remindVo.getVisibleRange());
                        logger.info("相关参数缺失！！!!!");
                        return;
                    }
                    try {
                        cloudEventPublisher.publish(Constans.MESSAGE_QUEUE, new EventWrapper<com.yizhi.message.application.vo.MessageRemindVo>(null, vo));
                        logger.info("发送消息成功=====================");
                    } catch (Exception e) {
                        e.printStackTrace();
                        logger.error("发送消息失败=====================", e);
                    }
                }
            }
        }
    }
}
